@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2013 ECMWF.
+# Copyright 2005-2014 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -16,10 +16,10 @@ cp ${data_dir}/regular_latlon_surface.grib1 ${data_dir}/regular_latlon_surface.g
 # Change the GRIB_SAMPLES_PATH: put the data dir first
 GRIB_SAMPLES_PATH=${data_dir}:${samples_dir}
 export GRIB_SAMPLES_PATH
-${examples_dir}samples > /dev/null
+${examples_dir}f_samples > /dev/null
 
 # Extend the GRIB_SAMPLES_PATH: put the data dir second
 GRIB_SAMPLES_PATH=${samples_dir}:${data_dir}
 export GRIB_SAMPLES_PATH
-${examples_dir}samples > /dev/null
+${examples_dir}f_samples > /dev/null
 
