@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -19,6 +19,7 @@
    IMPLEMENTS = init
    IMPLEMENTS = pack_double
    IMPLEMENTS = unpack_double
+   IMPLEMENTS = unpack_double_element
    IMPLEMENTS = value_count
    IMPLEMENTS = destroy
    MEMBERS=const char* half_byte
@@ -67,6 +68,7 @@ static long value_count(grib_accessor*);
 static void destroy(grib_context*,grib_accessor*);
 static void init(grib_accessor*,const long, grib_arguments* );
 static void init_class(grib_accessor_class*);
+static int unpack_double_element(grib_accessor*,size_t i, double* val);
 
 typedef struct grib_accessor_data_g1second_order_general_extended_packing {
     grib_accessor          att;
@@ -151,7 +153,7 @@ static grib_accessor_class _grib_accessor_class_data_g1second_order_general_exte
     0,      /* nearest_smaller_value */
     0,                       /* next accessor    */
     0,                    /* compare vs. another accessor   */
-    0,     /* unpack only ith value          */
+    &unpack_double_element,     /* unpack only ith value          */
     0,     /* unpack a subarray         */
     0,             		/* clear          */
 };
@@ -185,7 +187,6 @@ static void init_class(grib_accessor_class* c)
 	c->nearest_smaller_value	=	(*(c->super))->nearest_smaller_value;
 	c->next	=	(*(c->super))->next;
 	c->compare	=	(*(c->super))->compare;
-	c->unpack_double_element	=	(*(c->super))->unpack_double_element;
 	c->unpack_double_subarray	=	(*(c->super))->unpack_double_subarray;
 	c->clear	=	(*(c->super))->clear;
 }
@@ -204,11 +205,16 @@ static unsigned long nbits[32]={
                 0x40000000, 0x80000000
 };
 
-GRIB_INLINE static long number_of_bits(unsigned long x) {
-	unsigned long *n=nbits;
-	long i=0;
-	while (x>=*n) {n++;i++;}
-	return i;
+static long number_of_bits(unsigned long x) {
+    unsigned long *n=nbits;
+    const int count = sizeof(nbits)/sizeof(nbits[0]);
+    long i=0;
+    while (x>=*n) {
+        n++;
+        i++;
+        Assert(i<count);
+   }
+   return i;
 }
 
 static void init(grib_accessor* a,const long v, grib_arguments* args)
@@ -271,6 +277,24 @@ static long value_count(grib_accessor* a)
   return numberOfCodedValues+orderOfSPD;
 }
 
+static int unpack_double_element(grib_accessor* a, size_t idx, double* val)
+{
+    size_t size;
+    double* values;
+    int err=0;
+
+    err=grib_get_size(a->parent->h,"values",&size);
+    if (err) return err;
+    if (idx > size) return GRIB_INVALID_NEAREST;
+
+    values=grib_context_malloc_clear(a->parent->h->context,size*sizeof(double));
+    err=grib_get_double_array(a->parent->h,"values",values,&size);
+    if (err) return err;
+    *val=values[idx];
+    grib_context_free(a->parent->h->context,values);
+    return err;
+}
+
 static int unpack_double(grib_accessor* a, double* values, size_t *len)
 {
   grib_accessor_data_g1second_order_general_extended_packing* self =  (grib_accessor_data_g1second_order_general_extended_packing*)a;
@@ -290,7 +314,7 @@ static int unpack_double(grib_accessor* a, double* values, size_t *len)
   long orderOfSPD=0;
   long *SPD=0;
   long numberOfValues=0;
-  long bias;
+  long bias=0;
   long y=0,z=0,w=0;
   size_t k,ngroups;
 
@@ -350,7 +374,6 @@ static int unpack_double(grib_accessor* a, double* values, size_t *len)
 		  if(ret != GRIB_SUCCESS) return ret;
 	} 
 
-
 	X=grib_context_malloc_clear(a->parent->h->context,sizeof(long)*numberOfValues);
 
 	n=orderOfSPD;
@@ -407,11 +430,9 @@ static int unpack_double(grib_accessor* a, double* values, size_t *len)
 				w+=y;
 				X[i]=w;
 			}
-
 			break;
 	}
 
-
 	if (self->values) {
 		if (numberOfValues!=self->size) {
 			grib_context_free(a->parent->h->context,self->values);
@@ -575,7 +596,7 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
 	long maxA,minA;
 	long maxC,minC,offsetC;
 	long maxAC,minAC;
-	long range,bias,maxSPD;
+	long range,bias=0,maxSPD;
 	long firstOrderValuesMax,offset,groupLength,j,groupWidth,firstOrderValue,lengthOfSecondOrderValues;
 	long *groupLengths,*groupWidths,*firstOrderValues; 
 	/* long groupLengths[MAX_NUMBER_OF_GROUPS],groupWidths[MAX_NUMBER_OF_GROUPS],firstOrderValues[MAX_NUMBER_OF_GROUPS]; */
@@ -584,7 +605,7 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
 	long startGroupLength=15;
 	long incrementGroupLength=3;
 	long minGroupLength=3;
-	long widthOfSPD,widthOfBias;
+	long widthOfSPD=0,widthOfBias=0;
 	long *offsets;
 	long widthOfFirstOrderValues;
 	int computeGroupA=1;
@@ -1132,7 +1153,6 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
 
 	}
 
-
 	grib_buffer_replace(a, buffer, size,1,1);
 
 	grib_context_free(a->parent->h->context,buffer);
@@ -1142,7 +1162,6 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
 	grib_context_free(a->parent->h->context,firstOrderValues);
 
 	return ret;
-
 }
 
 static void destroy(grib_context* context,grib_accessor* a)
@@ -1152,6 +1171,4 @@ static void destroy(grib_context* context,grib_accessor* a)
         grib_context_free(context, self->values);
         self->values=NULL;
     }
-
 }
-
