@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -140,7 +140,7 @@ static int init(grib_iterator* i,grib_handle* h,grib_arguments *args){
   if (jScansPositively) {
     for(lai=0;lai<self->nam;lai++) {
       self->las[lai] = lats[istart--];
-      if (istart<0) istart=size-1;       /* this condition is always FALSE -- 'istart' is unsigned long */
+      /*if (istart<0) istart=size-1;  this condition is always FALSE -- 'istart' is unsigned long */
     }
   } else {
     for(lai=0;lai<self->nam;lai++) {
