@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -1235,3 +1235,33 @@ int parse_keyval_string(char* grib_tool, char* arg, int values_required, int def
 	return GRIB_SUCCESS;
 }
 
+/* Return 1 if the productDefinitionTemplateNumber (grib edition 2) is related to EPS */
+int is_productDefinitionTemplateNumber_EPS(long productDefinitionTemplateNumber)
+{
+    return (
+        productDefinitionTemplateNumber == 1 || productDefinitionTemplateNumber == 11 ||
+        productDefinitionTemplateNumber ==33 || productDefinitionTemplateNumber == 34 || /*simulated (synthetic) satellite data*/
+        productDefinitionTemplateNumber ==41 || productDefinitionTemplateNumber == 43 || /*atmospheric chemical constituents*/
+        productDefinitionTemplateNumber ==45 || productDefinitionTemplateNumber == 47    /*aerosols*/
+    );
+}
+
+/* Return 1 if the productDefinitionTemplateNumber (grib edition 2) is related to atmospheric chemical constituents */
+int is_productDefinitionTemplateNumber_Chemical(long productDefinitionTemplateNumber)
+{
+    return (
+        productDefinitionTemplateNumber == 40 ||
+        productDefinitionTemplateNumber == 41 ||
+        productDefinitionTemplateNumber == 42 ||
+        productDefinitionTemplateNumber == 43);
+}
+
+/* Return 1 if the productDefinitionTemplateNumber (grib edition 2) is related to aerosols */
+int is_productDefinitionTemplateNumber_Aerosol(long productDefinitionTemplateNumber)
+{
+    return (
+        productDefinitionTemplateNumber == 44 ||
+        productDefinitionTemplateNumber == 45 ||
+        productDefinitionTemplateNumber == 46 ||
+        productDefinitionTemplateNumber == 47);
+}
