@@ -1,9 +1,9 @@
 #!/bin/sh
-# Copyright 2005-2013 ECMWF.
+# Copyright 2005-2014 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-#
+# 
 # In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
@@ -16,14 +16,12 @@
 
 REDIRECT=/dev/null
 
-#set -eax 
-
 dir="${data_dir}/tigge/"
 temp1="temp.grib1_"
 temp2="temp.grib2_"
 
 # --- Do I want to exclude any file pattern from the comparison ?
-exclusion_pattern="tcw|ssr|str|skt|cap|ci|ttr"
+exclusion_pattern="tcw|ssr|str|skt|cap|ci|ttr|st|sm|sd|slhf|sshf"
 
 for file in `ls ${dir}/tigge_*.grib`
 do
@@ -32,15 +30,15 @@ exclude=`echo $file | awk " /$exclusion_pattern/ {print \"found\";} "`
 
 if [ -z "$exclude" ]; then
 
-	rm -f ${temp1} ${temp2} || true
+   rm -f ${temp1} ${temp2} || true
 
-    # 1 to 2 conversion check
-	${tools_dir}grib_set -s editionNumber=1 ${file} ${temp1} 2> $REDIRECT > $REDIRECT
-	${tools_dir}grib_compare -P -c data:n,geography:n ${temp1} ${file} 2> $REDIRECT > $REDIRECT
+   # 2 to 1 conversion check
+   ${tools_dir}grib_set -s editionNumber=1 ${file} ${temp1} 2> $REDIRECT > $REDIRECT
+   ${tools_dir}grib_compare -P -c data:n,geography:n ${temp1} ${file} 2> $REDIRECT > $REDIRECT
 
-    # 2 to 1 conversion check
-    ${tools_dir}grib_set -s editionNumber=2 ${temp1} ${temp2} 2> $REDIRECT > $REDIRECT
-	${tools_dir}grib_compare -P -c shortName,data:n,geography:n ${temp2} ${file} 2> $REDIRECT > $REDIRECT
+   # 1 to 2 conversion check
+   ${tools_dir}grib_set -s editionNumber=2 ${temp1} ${temp2} 2> $REDIRECT > $REDIRECT
+   ${tools_dir}grib_compare -P -c shortName,data:n,geography:n ${temp2} ${file} 2> $REDIRECT > $REDIRECT
 fi
 done
 
