@@ -1,4 +1,4 @@
-# Copyright 2005-2013 ECMWF.
+# Copyright 2005-2014 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,5 +14,9 @@ PACKAGE_NAME='grib_api'
 
 # Package version
 GRIB_API_MAJOR_VERSION=1
-GRIB_API_MINOR_VERSION=10
-GRIB_API_REVISION_VERSION=4
+GRIB_API_MINOR_VERSION=12
+GRIB_API_REVISION_VERSION=3
+
+GRIB_ABI_CURRENT=0
+GRIB_ABI_REVISION=0
+GRIB_ABI_AGE=0
